<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @since      1.0.0
 *
 * @package    Affiliate_Butler_Pro
 * @subpackage Affiliate_Butler_Pro/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Affiliate_Butler_Pro
 * @subpackage Affiliate_Butler_Pro/includes
 * @author     Waseem Senjer <waseem.senjer@gmail.com>
 */
class Affiliate_Butler_Pro {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Affiliate_Butler_Pro_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $Affiliate_Butler_Pro    The string used to uniquely identify this plugin.
	 */
	protected $Affiliate_Butler_Pro;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

		$this->Affiliate_Butler_Pro = 'affiliat-butler-pro';
		$this->version = '1.0.0';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Affiliate_Butler_Pro_Loader. Orchestrates the hooks of the plugin.
	 * - Affiliate_Butler_Pro_i18n. Defines internationalization functionality.
	 * - Affiliate_Butler_Pro_Admin. Defines all hooks for the admin area.
	 * - Affiliate_Butler_Pro_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {
		
	
		/**
		* Stats Class @PRO
		*
		**/
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class.stats.php';

		/**
		*
		* Base62 Class
		**/
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/classes/class.base62.php';

		/**
		* Link Class
		*
		**/
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/classes/class.link.php';

		/**
		 * The Metabox Library
		 * 
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/cmb/init.php';
		
		/**
		 *
		 * The Helper Class
		 * 
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/classes/class-settings.php';
		
		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-affiliate-butler-pro-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-affiliate-butler-pro-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-affiliate-butler-pro-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-affiliate-butler-pro-public.php';

		$this->loader = new Affiliate_Butler_Pro_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Affiliate_Butler_Pro_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Affiliate_Butler_Pro_i18n();
		$plugin_i18n->set_domain( $this->get_Affiliate_Butler_Pro() );

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );


	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Affiliate_Butler_Pro_Admin( $this->get_Affiliate_Butler_Pro(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'dequeue_conflicted_scripts', 150 );
		
		$this->loader->add_action( 'init', $plugin_admin, 'register_links_post_type' );
		
		// links categories
		$this->loader->add_action( 'init', $plugin_admin, 'register_taxonomies' );
		
	

		// internal linking
		$this->loader->add_action( 'wp_ajax_search_internal_linking', $plugin_admin, 'search_internal_linking' );

		
		
	
		//add jqvmap PRO feature
		if(isset($_GET['page']) && $_GET['page'] == 'lar_link_stats')
			$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'insert_jqvmap' );

		// add total clicks column content
		$this->loader->add_filter('manage_lar_link_posts_custom_column',$plugin_admin,'abutler_columns_content',10,2);
		
		// add total clicks head
		$this->loader->add_filter('lar_links_colums_heads',$plugin_admin,'abutler_columns_head');
		// add the (Stats) to quick links
		$this->loader->add_action('abutler_add_quick_links',$plugin_admin,'add_stats_link');


		// add internal linking variables
		$this->loader->add_action( 'abutler_add_js_variables', $plugin_admin, 'add_internal_variables' );


		// validate internal and external
		$this->loader->add_filter('abutler_post_validate_link',$plugin_admin,'pre_submit_link_validation',10,2);


		// add the "Stats Page"
		$this->loader->add_action('abutler_add_custom_pages',$plugin_admin,'add_stats_page');
		
		$this->loader->add_filter('abutler_put_colums_before',$plugin_admin,'before_column');


		$this->loader->add_action('cmb2_init',$plugin_admin, 'lar_links_register_metabox');
		$this->loader->add_action( 'wp_ajax_my_pre_submit_validation', $plugin_admin, 'pre_submit_link_validation' );
		

		if(isset($_GET['post_type']) OR isset($_GET['post'])){
			if( (isset($_GET['post_type']) && $_GET['post_type'] == 'lar_link') OR (isset($_GET['post']) && get_post_type($_GET['post'])=='lar_link')){
				$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'insert_validation_nonce' );
			}
		}
		

		// disabled for individual posts
		$this->loader->add_action( 'add_meta_boxes', $plugin_admin, 'disable_for_single_post' );
		$this->loader->add_action( 'add_meta_boxes', $plugin_admin, 'keyword_stats_box' );
		$this->loader->add_action( 'save_post', $plugin_admin, 'abutler_meta_save' );
		

		// edit the admin columns
		$this->loader->add_filter('manage_lar_link_posts_columns', $plugin_admin, 'abutler_columns_head');
		$this->loader->add_filter('manage_lar_link_posts_custom_column', $plugin_admin, 'abutler_columns_content',10,2);
		
		// @since 1.0.0
		$this->loader->add_filter( 'post_row_actions', $plugin_admin, 'remove_row_actions', 10, 2 );

		// @since 1.1.0
		$this->loader->add_action('admin_menu', $plugin_admin, 'add_abutler_docs_link_to_menu',	105);
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Affiliate_Butler_Pro_Public( $this->get_Affiliate_Butler_Pro(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );


		$this->loader->add_action( 'wp_ajax_store_stats', $plugin_public , 'store_stats' );
		$this->loader->add_action( 'lar_link_redirected',$plugin_public,'save_new_stat_record');

		// add class link_id as an extra atts
		$this->loader->add_filter( 'abutler_add_extra_atts',$plugin_public,'add_extra_atts',10,2);		
		if(!is_admin()){		
			$this->loader->add_filter( 'the_content', $plugin_public, 'abutler_auto_replace_links',1500 );
			$this->loader->add_filter( 'the_excerpt', $plugin_public, 'abutler_auto_replace_links_excerpt',1500 );
		}
		
		$this->loader->add_filter( 'rewrite_rules_array', $plugin_public, 'abutler_setup_rewrite_rules' );
		$this->loader->add_filter( 'query_vars', $plugin_public, 'add_go_variable' );
		$this->loader->add_action( 'template_redirect', $plugin_public, 'abutler_redirect' );

	}




	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_Affiliate_Butler_Pro() {
		return $this->Affiliate_Butler_Pro;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Affiliate_Butler_Pro_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
